<?php 
/**
* Registers a new post type
* @uses $wp_post_types Inserts new post type object into the list
*
* @param string  Post type key, must not exceed 20 characters
* @param array|string  See optional args description above.
* @return object|WP_Error the registered post type object, or an error object
*/
if ( ! function_exists( 'GS_Team' ) ) {

	function GS_Team() {
		$labels = array(
			'name'               => _x( 'Teams', 'gsteam' ),
			'singular_name'      => _x( 'Team', 'gsteam' ),
			'menu_name'          => _x( 'GS Team', 'admin menu', 'gsteam' ),
			'name_admin_bar'     => _x( 'GS Team', 'add new on admin bar', 'gsteam' ),
			'add_new'            => _x( 'Add New Member', 'team', 'gsteam' ),
			'add_new_item'       => __( 'Add New Member', 'gsteam' ),
			'new_item'           => __( 'New Team', 'gsteam' ),
			'edit_item'          => __( 'Edit Team', 'gsteam' ),
			'view_item'          => __( 'View Team', 'gsteam' ),
			'all_items'          => __( 'All Members', 'gsteam' ),
			'search_items'       => __( 'Search Members', 'gsteam' ),
			'parent_item_colon'  => __( 'Parent Teams:', 'gsteam' ),
			'not_found'          => __( 'No Teams found.', 'gsteam' ),
			'not_found_in_trash' => __( 'No Teams found in Trash.', 'gsteam' ),
		);

		$gs_teammembers_slug  = gs_team_getoption('gs_teammembers_slug', 'gs_team_adv_settings', 'team-members');

		$args = array(
			'labels'             => $labels,
			'public'             => true,
			'publicly_queryable' => true,
			'show_ui'            => true,
			'show_in_menu'       => true,
			'query_var'          => true,
			'rewrite'            => array( 'slug' => $gs_teammembers_slug ),
			'capability_type'    => 'post',
			'has_archive'        => true,
			'hierarchical'       => false,
			'menu_position'      => GSTEAM_MENU_POSITION,
			'menu_icon'          => 'dashicons-image-filter',
			'supports'           => array( 'title', 'editor','thumbnail')
		);

		register_post_type( 'gs_team', $args );
	}
}

add_action( 'init', 'GS_Team' );

 // =============taxonomy==================
// if ( gtm_fs()->is__premium_only() or gtm_fs()->can_use_premium_code() ) {
	
	if ( ! function_exists( 'gs_team_group' ) ) {
	// Register Custom Taxonomy For Team
	function gs_team_group() {

		$labels = array(
			'name'                       => _x( 'Team Group', 'Taxonomy General Name', 'gsteam' ),
			'singular_name'              => _x( 'Team Group', 'Taxonomy Singular Name', 'gsteam' ),
			'menu_name'                  => __( 'Team Group', 'gsteam' ),
			'all_items'                  => __( 'All Team Group', 'gsteam' ),
			'parent_item'                => __( 'Parent Team Group', 'gsteam' ),
			'parent_item_colon'          => __( 'Parent Team Group:', 'gsteam' ),
			'new_item_name'              => __( 'New Team Group', 'gsteam' ),
			'add_new_item'               => __( 'Add New Team Group', 'gsteam' ),
			'edit_item'                  => __( 'Edit Team Group', 'gsteam' ),
			'update_item'                => __( 'Update Team Group', 'gsteam' ),
			'separate_items_with_commas' => __( 'Separate Team Group with commas', 'gsteam' ),
			'search_items'               => __( 'Search Team Group', 'gsteam' ),
			'add_or_remove_items'        => __( 'Add or remove Team Group', 'gsteam' ),
			'choose_from_most_used'      => __( 'Choose from the most used Team Groups', 'gsteam' ),
			'not_found'                  => __( 'Not Found', 'gsteam' ),
		);
		$rewrite = array(
			'slug'                       => 'gs-team-group',
			'with_front'                 => true,
			'hierarchical'               => false,
		);
		$args = array(
			'labels'                     => $labels,
			'hierarchical'               => true,
			'public'                     => true,
			'show_ui'                    => true,
			'show_admin_column'          => true,
			'show_in_nav_menus'          => false,
			'show_tagcloud'              => false,
			'rewrite'                    => $rewrite,
		);
		register_taxonomy( 'team_group', array( 'gs_team' ), $args );

	}

	// Hook into the 'init' action
	add_action( 'init', 'gs_team_group', 0 );
	}
// }

// Register Theme Features (feature image for Team)
if ( ! function_exists('gs_team_theme_support') ) {

	function gs_team_theme_support()  {
		// Add theme support for Featured Images
		add_theme_support( 'post-thumbnails', array( 'gs_team' ) );
		add_theme_support( 'post-thumbnails', array( 'post' ) ); // Add it for posts
		add_theme_support( 'post-thumbnails', array( 'page' ) ); // Add it for pages
		add_theme_support( 'post-thumbnails', array( 'product' ) ); // Add it for products
		add_theme_support( 'post-thumbnails');
		// Add Shortcode support in text widget
		add_filter('widget_text', 'do_shortcode'); 
	}

	// Hook into the 'after_setup_theme' action
	add_action( 'after_setup_theme', 'gs_team_theme_support' );
}